/**
 * Created by irazer on 13/03/17.
 */
(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "request"], factory);
    }
})(function (require, exports) {
    "use strict";
    var request = require("request");
    var OneDrive = (function () {
        function OneDrive(authClient) {
            this.authClient = authClient;
            this.BASE_URI = 'https://graph.microsoft.com/v1.0';
        }
        OneDrive.prototype.listDrive = function (callback) {
            var _this = this;
            request.get(this.BASE_URI + "/drives", {
                auth: {
                    bearer: this.authClient.credentials.access_token
                }
            }, function (err, res, body) {
                _this._parseBody(err, res, body, callback);
            });
        };
        OneDrive.prototype.getDefaultDrive = function (callback) {
            var _this = this;
            request.get(this.BASE_URI + "/drive", {
                auth: {
                    bearer: this.authClient.credentials.access_token
                }
            }, function (err, res, body) {
                _this._parseBody(err, res, body, callback);
            });
        };
        OneDrive.prototype.getDrive = function (id, callback) {
            var _this = this;
            request.get(this.BASE_URI + "/drive/" + id, {
                auth: {
                    bearer: this.authClient.credentials.access_token
                }
            }, function (err, res, body) {
                _this._parseBody(err, res, body, callback);
            });
        };
        OneDrive.prototype.getChildrenById = function (id, callback) {
            var _this = this;
            request.get(this.BASE_URI + "/drive/items/" + id + "/children", {
                auth: {
                    bearer: this.authClient.credentials.access_token
                }
            }, function (err, res, body) {
                _this._parseBody(err, res, body, callback);
            });
        };
        OneDrive.prototype.getChildren = function (path, callback) {
            var _this = this;
            request.get(this.BASE_URI + "/drive/" + path + "/children", {
                auth: {
                    bearer: this.authClient.credentials.access_token
                }
            }, function (err, res, body) {
                _this._parseBody(err, res, body, callback);
            });
        };
        OneDrive.prototype._parseBody = function (err, res, body, callback) {
            if (err) {
                return callback(err, null);
            }
            if (body && res.headers['content-type'] === 'application/json') {
                callback(null, JSON.parse(body));
            }
            else {
                callback(null, body);
            }
        };
        return OneDrive;
    }());
    exports.OneDrive = OneDrive;
});

/**
 * Created by irazer on 16/03/17.
 */
(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "query-string", "request"], factory);
    }
})(function (require, exports) {
    "use strict";
    var querystring = require("query-string");
    var request = require("request");
    var AuthClient = (function () {
        function AuthClient(clientId, clientSecret, redirectUri) {
            this.clientId = clientId;
            this.clientSecret = clientSecret;
            this.redirectUri = redirectUri;
            this.BASE_URI = 'https://login.microsoftonline.com/common/oauth2/v2.0';
        }
        Object.defineProperty(AuthClient.prototype, "credentials", {
            get: function () {
                return this._credentials;
            },
            set: function (value) {
                this._credentials = value;
            },
            enumerable: true,
            configurable: true
        });
        AuthClient.prototype.getAuthenticationUrl = function (scopes) {
            if (!scopes) {
                throw new Error('Scopes must be provided');
            }
            if (!this.redirectUri) {
                throw new Error('The redirect URI must be provided');
            }
            if (!this.clientId) {
                throw new Error('A client id is required');
            }
            var parameters = {
                client_id: this.clientId,
                redirect_uri: this.redirectUri,
                scope: scopes.join(' '),
                response_type: 'code'
            };
            return this.BASE_URI + "/authorize?" + querystring.stringify(parameters);
        };
        AuthClient.prototype.getToken = function (code, callback) {
            request.post({
                url: this.BASE_URI + "/token",
                form: {
                    client_id: this.clientId,
                    redirect_uri: this.redirectUri,
                    client_secret: this.clientSecret,
                    code: code,
                    grant_type: 'authorization_code'
                }
            }, function (err, res, body) {
                if (err) {
                    return callback(err, null);
                }
                if (body && res.headers['content-type'] === 'application/json') {
                    callback(null, JSON.parse(body));
                }
                else {
                    callback(null, body);
                }
            });
        };
        AuthClient.prototype.refreshToken = function (refreshToken, callback) {
            request.post({
                url: this.BASE_URI + "/token",
                form: {
                    client_id: this.clientId,
                    redirect_uri: this.redirectUri,
                    client_secret: this.clientSecret,
                    refresh_token: refreshToken,
                    grant_type: 'refresh_token'
                }
            }, function (err, res, body) {
                if (err) {
                    return callback(err, null);
                }
                if (body && res.headers['content-type'] === 'application/json') {
                    callback(null, JSON.parse(body));
                }
                else {
                    callback(null, body);
                }
            });
        };
        return AuthClient;
    }());
    exports.AuthClient = AuthClient;
});

//# sourceMappingURL=node-onedrive.js.map
