/**
 * Created by irazer on 20/03/17.
 */

let gulp = require('gulp');
let typescript = require('gulp-typescript');
let tslint = require('gulp-tslint');
let sourcemaps = require('gulp-sourcemaps');
let concat = require('gulp-concat');
let uglify = require('gulp-uglify');
let rename = require('gulp-rename');
let del = require('del');
let Server = require('karma').Server;
let path = require('path');

let tsConfig = require('./tsconfig.json');
tsConfig.compilerOptions.module = 'umd';
tsConfig.compilerOptions.sourceMap = false;

paths = {
  dist: 'dist',
  src: 'src'
};

gulp.task('cleanup', () => {
  return del.sync(paths.dist);
});

gulp.task('copy', ['cleanup'], () => {
  return gulp.src(path.join(paths.src, '@types', '*.d.ts'))
    .pipe(gulp.dest(path.join(paths.dist, '@types')));
});

gulp.task('unit', ['cleanup'], (done) => {
  new Server({
    configFile: path.join(__dirname, 'karma.conf.js')
  }, done).start();
});

gulp.task('tslint', ['cleanup'], () => {
  return gulp.src(path.join(paths.src, '**/*.ts'))
    .pipe(tslint({
      formatter: 'verbose'
    }))
    .pipe(tslint.report());
});

gulp.task('typescript', ['cleanup', 'tslint', 'unit'], () => {
  return gulp.src([
    path.join(paths.src, '**/*.ts'),
    `!${path.join(paths.src, '**/*.spec.ts')}`
  ])
    .pipe(sourcemaps.init())
      .pipe(typescript(tsConfig.compilerOptions)).js
      .pipe(concat('node-onedrive.js'))
    .pipe(sourcemaps.write('.'))
    .pipe(gulp.dest(paths.dist));
});

gulp.task('minify', ['typescript'], () => {
  return gulp.src(path.join(paths.dist, 'node-onedrive.js'))
    .pipe(uglify())
    .pipe(rename('node-onedrive.min.js'))
    .pipe(gulp.dest(path.join(paths.dist)))
});

gulp.task('default', ['cleanup', 'copy', 'typescript', 'minify']);
