/**
 * Created by irazer on 16/03/17.
 */
"use strict";
var querystring = require("query-string");
var request = require("request");
var AuthClient = (function () {
    function AuthClient(clientId, clientSecret, redirectUri) {
        this.clientId = clientId;
        this.clientSecret = clientSecret;
        this.redirectUri = redirectUri;
        this.BASE_URI = 'https://login.microsoftonline.com/common/oauth2/v2.0';
    }
    Object.defineProperty(AuthClient.prototype, "credentials", {
        get: function () {
            return this._credentials;
        },
        set: function (value) {
            this._credentials = value;
        },
        enumerable: true,
        configurable: true
    });
    AuthClient.prototype.getAuthenticationUrl = function (scopes) {
        if (!scopes) {
            throw new Error('Scopes must be provided');
        }
        if (!this.redirectUri) {
            throw new Error('The redirect URI must be provided');
        }
        if (!this.clientId) {
            throw new Error('A client id is required');
        }
        var parameters = {
            client_id: this.clientId,
            redirect_uri: this.redirectUri,
            scope: scopes.join(' '),
            response_type: 'code'
        };
        return this.BASE_URI + "/authorize?" + querystring.stringify(parameters);
    };
    AuthClient.prototype.getToken = function (code, callback) {
        request.post({
            url: this.BASE_URI + "/token",
            form: {
                client_id: this.clientId,
                redirect_uri: this.redirectUri,
                client_secret: this.clientSecret,
                code: code,
                grant_type: 'authorization_code'
            }
        }, function (err, res, body) {
            if (err) {
                return callback(err, null);
            }
            if (body && res.headers['content-type'] === 'application/json') {
                callback(null, JSON.parse(body));
            }
            else {
                callback(null, body);
            }
        });
    };
    AuthClient.prototype.refreshToken = function (refreshToken, callback) {
        request.post({
            url: this.BASE_URI + "/token",
            form: {
                client_id: this.clientId,
                redirect_uri: this.redirectUri,
                client_secret: this.clientSecret,
                refresh_token: refreshToken,
                grant_type: 'refresh_token'
            }
        }, function (err, res, body) {
            if (err) {
                return callback(err, null);
            }
            if (body && res.headers['content-type'] === 'application/json') {
                callback(null, JSON.parse(body));
            }
            else {
                callback(null, body);
            }
        });
    };
    return AuthClient;
}());
exports.AuthClient = AuthClient;
//# sourceMappingURL=authClient.js.map