/**
 * Created by irazer on 16/03/17.
 */

import * as querystring from 'query-string';
import * as request from 'request';


export class AuthClient {

  private BASE_URI = 'https://login.microsoftonline.com/common/oauth2/v2.0';

  private _credentials: any;

  constructor(private clientId: string,
              private clientSecret: string,
              private redirectUri: string) {
  }

  public get credentials(): any {
    return this._credentials;
  }

  public set credentials(value: any) {
    this._credentials = value;
  }

  public getAuthenticationUrl(scopes: string[]): string {

    if (!scopes) {
      throw new Error('Scopes must be provided');
    }

    if (!this.redirectUri) {
      throw new Error('The redirect URI must be provided');
    }

    if (!this.clientId) {
      throw new Error('A client id is required');
    }

    let parameters = {
      client_id: this.clientId,
      redirect_uri: this.redirectUri,
      scope: scopes.join(' '),
      response_type: 'code'
    };

    return `${this.BASE_URI}/authorize?${querystring.stringify(parameters)}`;
  }

  public getToken(code: string, callback: (error: any, body: any) => void): void {
    request.post({
      url: `${this.BASE_URI}/token`,
      form: {
        client_id: this.clientId,
        redirect_uri: this.redirectUri,
        client_secret: this.clientSecret,
        code,
        grant_type: 'authorization_code'
      }
    }, (err, res, body) => {
      if (err) {
        return callback(err, null);
      }

      if (body && res.headers['content-type'] === 'application/json') {
        callback(null, JSON.parse(body));
      } else {
        callback(null, body);
      }
    });
  }

  public refreshToken(refreshToken: string, callback: (err: any, res: any) => void): void {
    request.post({
      url: `${this.BASE_URI}/token`,
      form: {
        client_id: this.clientId,
        redirect_uri: this.redirectUri,
        client_secret: this.clientSecret,
        refresh_token: refreshToken,
        grant_type: 'refresh_token'
      }
    }, (err, res, body) => {
      if (err) {
        return callback(err, null);
      }

      if (body && res.headers['content-type'] === 'application/json') {
        callback(null, JSON.parse(body));
      } else {
        callback(null, body);
      }
    });
  }
}
