/**
 * Created by irazer on 13/03/17.
 */
"use strict";
var request = require("request");
var OneDrive = (function () {
    function OneDrive(authClient) {
        this.authClient = authClient;
        this.BASE_URI = 'https://graph.microsoft.com/v1.0';
    }
    OneDrive.prototype.listDrive = function (callback) {
        var _this = this;
        request.get(this.BASE_URI + "/drives", {
            auth: {
                bearer: this.authClient.credentials.access_token
            }
        }, function (err, res, body) {
            _this._parseBody(err, res, body, callback);
        });
    };
    OneDrive.prototype.getDefaultDrive = function (callback) {
        var _this = this;
        request.get(this.BASE_URI + "/drive", {
            auth: {
                bearer: this.authClient.credentials.access_token
            }
        }, function (err, res, body) {
            _this._parseBody(err, res, body, callback);
        });
    };
    OneDrive.prototype.getDrive = function (id, callback) {
        var _this = this;
        request.get(this.BASE_URI + "/drive/" + id, {
            auth: {
                bearer: this.authClient.credentials.access_token
            }
        }, function (err, res, body) {
            _this._parseBody(err, res, body, callback);
        });
    };
    OneDrive.prototype.getChildrenById = function (id, callback) {
        var _this = this;
        request.get(this.BASE_URI + "/drive/items/" + id + "/children", {
            auth: {
                bearer: this.authClient.credentials.access_token
            }
        }, function (err, res, body) {
            _this._parseBody(err, res, body, callback);
        });
    };
    OneDrive.prototype.getChildren = function (path, callback) {
        var _this = this;
        request.get(this.BASE_URI + "/drive/" + path + "/children", {
            auth: {
                bearer: this.authClient.credentials.access_token
            }
        }, function (err, res, body) {
            _this._parseBody(err, res, body, callback);
        });
    };
    OneDrive.prototype._parseBody = function (err, res, body, callback) {
        if (err) {
            return callback(err, null);
        }
        if (body && res.headers['content-type'] === 'application/json') {
            callback(null, JSON.parse(body));
        }
        else {
            callback(null, body);
        }
    };
    return OneDrive;
}());
exports.OneDrive = OneDrive;
//# sourceMappingURL=onedrive.js.map