/**
 * Created by irazer on 15/03/17.
 */
"use strict";
var nock = require("nock");
var authClient_1 = require("./auth/authClient");
var onedrive_1 = require("./onedrive");
var BASE_URI = 'https://graph.microsoft.com/v1.0';
describe('node-onedrive', function () {
    beforeEach(function () {
        nock.disableNetConnect();
    });
    it('should call the list drive api', function (done) {
        nock(BASE_URI, {
            reqheaders: {
                'Authorization': 'Bearer 1234'
            }
        })
            .get('/drives')
            .reply(200, {
            value: 'test value'
        }, {
            'Content-Type': 'application/json'
        });
        var authClient = new authClient_1.AuthClient(null, null, null);
        authClient.credentials = {
            access_token: '1234'
        };
        var client = new onedrive_1.OneDrive(authClient);
        client.listDrive(function (err, data) {
            expect(data.value).toBe('test value');
            nock.cleanAll();
            done();
        });
    });
    it('should call the get default drive api', function (done) {
        nock(BASE_URI, {
            reqheaders: {
                'Authorization': 'Bearer 1234'
            }
        })
            .get('/drive')
            .reply(200, {
            value: 'test value'
        }, {
            'Content-Type': 'application/json'
        });
        var authClient = new authClient_1.AuthClient(null, null, null);
        authClient.credentials = {
            access_token: '1234'
        };
        var client = new onedrive_1.OneDrive(authClient);
        client.getDefaultDrive(function (err, data) {
            expect(data.value).toBe('test value');
            nock.cleanAll();
            done();
        });
    });
    it('should call the get drive api', function (done) {
        nock(BASE_URI, {
            reqheaders: {
                'Authorization': 'Bearer 1234'
            }
        })
            .get('/drive/1234')
            .reply(200, {
            value: 'test value'
        }, {
            'Content-Type': 'application/json'
        });
        var authClient = new authClient_1.AuthClient(null, null, null);
        authClient.credentials = {
            access_token: '1234'
        };
        var client = new onedrive_1.OneDrive(authClient);
        client.getDrive('1234', function (err, data) {
            expect(data.value).toBe('test value');
            nock.cleanAll();
            done();
        });
    });
    it('should call the get children by id api', function (done) {
        nock(BASE_URI, {
            reqheaders: {
                'Authorization': 'Bearer 1234'
            }
        })
            .get('/drive/items/1234/children')
            .reply(200, {
            value: 'test value'
        }, {
            'Content-Type': 'application/json'
        });
        var authClient = new authClient_1.AuthClient(null, null, null);
        authClient.credentials = {
            access_token: '1234'
        };
        var client = new onedrive_1.OneDrive(authClient);
        client.getChildrenById('1234', function (err, data) {
            expect(data.value).toBe('test value');
            nock.cleanAll();
            done();
        });
    });
    it('should call the get children by path api', function (done) {
        nock(BASE_URI, {
            reqheaders: {
                'Authorization': 'Bearer 1234'
            }
        })
            .get('/drive/test/drive/children')
            .reply(200, {
            value: 'test value'
        }, {
            'Content-Type': 'application/json'
        });
        var authClient = new authClient_1.AuthClient(null, null, null);
        authClient.credentials = {
            access_token: '1234'
        };
        var client = new onedrive_1.OneDrive(authClient);
        client.getChildren('test/drive', function (err, data) {
            expect(data.value).toBe('test value');
            nock.cleanAll();
            done();
        });
    });
});
//# sourceMappingURL=onedrive.spec.js.map