/**
 * Created by irazer on 15/03/17.
 */

import * as nock from 'nock';
import { AuthClient } from './auth/authClient';
import { OneDrive } from './onedrive';

const BASE_URI = 'https://graph.microsoft.com/v1.0';

describe('node-onedrive', () => {
  beforeEach(() => {
    nock.disableNetConnect();
  });

  it('should call the list drive api', (done) => {
    nock(BASE_URI, {
      reqheaders: {
        'Authorization': 'Bearer 1234'
      }
    })
      .get('/drives')
      .reply(200, {
        value: 'test value'
      }, {
        'Content-Type': 'application/json'
      });

    let authClient = new AuthClient(null, null, null);
    authClient.credentials = {
      access_token: '1234'
    };

    let client = new OneDrive(authClient);
    client.listDrive((err, data) => {
      expect(data.value).toBe('test value');

      nock.cleanAll();
      done();
    });
  });

  it('should call the get default drive api', (done) => {
    nock(BASE_URI, {
      reqheaders: {
        'Authorization': 'Bearer 1234'
      }
    })
      .get('/drive')
      .reply(200, {
        value: 'test value'
      }, {
        'Content-Type': 'application/json'
      });

    let authClient = new AuthClient(null, null, null);
    authClient.credentials = {
      access_token: '1234'
    };

    let client = new OneDrive(authClient);
    client.getDefaultDrive((err, data) => {
      expect(data.value).toBe('test value');

      nock.cleanAll();
      done();
    });
  });

  it('should call the get drive api', (done) => {
    nock(BASE_URI, {
      reqheaders: {
        'Authorization': 'Bearer 1234'
      }
    })
      .get('/drive/1234')
      .reply(200, {
        value: 'test value'
      }, {
        'Content-Type': 'application/json'
      });

    let authClient = new AuthClient(null, null, null);
    authClient.credentials = {
      access_token: '1234'
    };

    let client = new OneDrive(authClient);
    client.getDrive('1234', (err, data) => {
      expect(data.value).toBe('test value');

      nock.cleanAll();
      done();
    });
  });

  it('should call the get children by id api', (done) => {
    nock(BASE_URI, {
      reqheaders: {
        'Authorization': 'Bearer 1234'
      }
    })
      .get('/drive/items/1234/children')
      .reply(200, {
        value: 'test value'
      }, {
        'Content-Type': 'application/json'
      });

    let authClient = new AuthClient(null, null, null);
    authClient.credentials = {
      access_token: '1234'
    };

    let client = new OneDrive(authClient);
    client.getChildrenById('1234', (err, data) => {
      expect(data.value).toBe('test value');

      nock.cleanAll();
      done();
    });
  });

  it('should call the get children by path api', (done) => {
    nock(BASE_URI, {
      reqheaders: {
        'Authorization': 'Bearer 1234'
      }
    })
      .get('/drive/test/drive/children')
      .reply(200, {
        value: 'test value'
      }, {
        'Content-Type': 'application/json'
      });

    let authClient = new AuthClient(null, null, null);
    authClient.credentials = {
      access_token: '1234'
    };

    let client = new OneDrive(authClient);
    client.getChildren('test/drive', (err, data) => {
      expect(data.value).toBe('test value');

      nock.cleanAll();
      done();
    });
  });
});
