/**
 * Created by irazer on 13/03/17.
 */

import * as request from 'request';
import { RequestResponse } from 'request';

import { AuthClient } from './auth/authClient';

export class OneDrive {
  private BASE_URI = 'https://graph.microsoft.com/v1.0';

  constructor(private authClient: AuthClient) {
  }

  public listDrive(callback: (err: any, data: any) => void): void {
    request.get(`${this.BASE_URI}/drives`, {
      auth: {
        bearer: this.authClient.credentials.access_token
      }
    }, (err, res, body) => {
      this._parseBody(err, res, body, callback);
    });
  }

  public getDefaultDrive(callback: (err: any, data: any) => void): void {
    request.get(`${this.BASE_URI}/drive`, {
      auth: {
        bearer: this.authClient.credentials.access_token
      }
    }, (err, res, body) => {
      this._parseBody(err, res, body, callback);
    });
  }

  public getDrive(id: string, callback: (err: any, data: any) => void): void {
    request.get(`${this.BASE_URI}/drive/${id}`, {
      auth: {
        bearer: this.authClient.credentials.access_token
      }
    }, (err, res, body) => {
      this._parseBody(err, res, body, callback);
    });
  }

  public getChildrenById(id: string, callback: (err: any, data: any) => void): void {
    request.get(`${this.BASE_URI}/drive/items/${id}/children`, {
      auth: {
        bearer: this.authClient.credentials.access_token
      }
    }, (err, res, body) => {
      this._parseBody(err, res, body, callback);
    });
  }

  public getChildren(path: string, callback: (err: any, data: any) => void): void {
    request.get(`${this.BASE_URI}/drive/${path}/children`, {
      auth: {
        bearer: this.authClient.credentials.access_token
      }
    }, (err, res, body) => {
      this._parseBody(err, res, body, callback);
    });
  }

  private _parseBody(err: any, res: RequestResponse, body: any, callback: (err: any, data: any) => void) {
    if (err) {
      return callback(err, null);
    }

    if (body && res.headers['content-type'] === 'application/json') {
      callback(null, JSON.parse(body));
    } else {
      callback(null, body);
    }
  }
}
